<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>שגיאה בקובץ config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>שגיאה בהרצת פלאג-אין:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>אין אפשרות לטעון את הקובץ.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>תצורת קובץ בלתי תקינה.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>אין אפשרות לשמור את הקובץ.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>אין אפשרות לנתח את קובץ ה-XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>קידוד לא מזוהה.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>תשובה חסרה בשורה:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>אין אפשרות לטעון את בסיס הנתונים.
יוצר קובץ זמני.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>מנימוסינה</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>קובץ קיים:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;החלף</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>כפילויות שהוסרו: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>ישנן כרטיסיות בעלות תשובות שונות עבור השאלה:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;מזג וערוך</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;אל תמזג</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>הושלם!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">אינכם זוכרים כרטיסיה זו עדיין.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">כמו &apos;0&apos;, אבל נהיה מוכר יותר.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"> הצג זאת לעתים רחוקות יותר.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">כעת אתם זוכרים כרטיסיה זו</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> וככל הנראה תזכרו אותה במשך מספר ימים.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">שכחתם כרטיסיה זו לחלוטין.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">תשובה כמעט נכונה. ההשהייה בהחלט הייתה ארוכה מדי.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">תשובה נכונה, אבל תוך מאמץ ניכר.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> ההשהייה כנראה הייתה ארוכה מדי.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">תשובה נכונה, תוך מאמץ מסויים.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished"> ההשהייה כנראה התאימה בדיוק.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">תשובה נכונה, אבל ללא כל</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> קושי. ההשהייה כנראה הייתה קצרה מדי.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>מנימוסינה</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>יוצר ראשי: פיטר בינסטמן

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>מידע נוסף: http://mnemosyne-proj.org
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>על התוכנה</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>הפעל קטגוריות</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>בחר קטגוריות להפעלה:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>אל תפעיל כלום</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>הפעל הכל</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;ברירת מחדל&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>מנימוסינה</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>לנטוש את הכרטיסיה הנוכחית?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;כן</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;לא</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>תשובה:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>צורה כתובה:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>תרגום:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>הכרטיסיה כבר נמצאת בבסיס הנתונים.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>הכפילות לא נכנסה למאגר.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>ישנן תשובות שונות עבור</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> שאלה זו:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;מזג וערוך</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;הוסף כך</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;אל תוסיף</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>הוסף כרטיסיות</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>קטגוריה:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>הגייה:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>תשובה:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>הוסף גם את ה&amp;היפך</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>בחר ציון התחלתי:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>אינכם זוכרים פריט זה עדיין, או ששכחתם אותו.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>כמו &apos;0&apos;, אבל נהיה מוכר יותר.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>כעת אתם זוכרים כרטיסיה זו וככל הנראה תזכרו אותה במשך מספר ימים.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>תשובה נכונה, אבל תוך מאמץ ניכר. ההשהייה כנראה הייתה ארוכה מדי</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>תשובה נכונה, תוך מאמץ מסויים. ההשהייה כנראה התאימה בדיוק.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>תשובה נכונה, אבל ללא כל קושי. ההשהייה כנראה הייתה קצרה מדי.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>הקלידו את השאלה והתשובה ואז בחרו ציון התחלתי.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;תצוגה מקדימה</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;יציאה</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>תצוגה מקדימה</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>שינוי קטגוריה</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>קטגוריה:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>אפשרויות מנימוסינה</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>השהה את הסמן מעל הלחצנים לקבלת מידע נוסף.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>קבע גופן שאלות\תשובות</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>קבע את הגופן שיופיע בהצגת שאלות ותשובות בודדות</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>קבע גופן רשימה</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>קבע את הגופן שיופיע בהצגת רשימת כל הכרטיסיות בחפיסה</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>הגדל את הגופן של תווים שאינם לטיניים ב-</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>לעתים, קשה לקרוא סמלים מסובכים בגודל ברירת-המחדל של גופנים לטיניים</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>נקודות</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>שליחת תיעוד</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>שלח תיעוד אנונימי</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>שתף סטטיסטיקה אנונימית בכדי לתרום למחקר על זיכרון</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>טיפול בכפילויות</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>בדוק אם יש כפילויות בהוספת כרטיסיות חדשות</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>אפשר כפילויות בקטגוריות שונות</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>תהליך למידה</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">מספר הכרטיסיות עם ציון 0 ללמוד בבת אחת (אחת אחרי השנייה):</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>הערה: זה *אינו* מספר הכרטיסיות עם ציון 0 שברצונך ללמוד בכל יום</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>ברירת מחדל</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>למד כרטיסיות חדשות בסדר אקראי</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>ערוך כרטיסיה</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>קטגוריה:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>תשובה:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;תצוגה מקדימה</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>אנא המתינו...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;עריכה</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;תצוגה מקדימה</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>הוסף את ה&amp;היפך</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>&amp;סטטיסטיקה</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;מחיקה</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;שינוי תיקייה</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>הוסף את ה&amp;היפך</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>להוסיף את ההיפך של כרטיסיות אלו?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>להוסיף את ההיפך של כרטיסיה זו?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>מנימוסינה</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

פעולה זו עלולה ליצור כפילויות אם ההפכים </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>של כרטיסיות אלו כבר נמצאים, אז אולי תרצו להריץ</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>&quot;נקה כפילויות&quot; לאחר מכן.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;כן</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;לא</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>ציון:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>קלות:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>מספר חזרות:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>מספר טעויות:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>מספר ימים מאז החזרה האחרונה:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>מספר ימים עד החזרה הבאה:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>למחוק כרטיסיות אלה?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>למחוק כרטיסיה זו?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>הטקסט שהכנסת לא נמצא.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;מצא שוב</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;מצא</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>תשובה</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>קטגוריה</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;מצא</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>בכדי לערוך כרטיסיה, לחצו לחיצה ימנית עליה.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;יציאה</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+F</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>כל הקבצים (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ייצוא</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>ייצוא לקובץ</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>סוג הקובץ:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>הקובץ לייצוא:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;עיון</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>קטגוריות לייצוא:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;בחר הכל</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>מחק את המידע על הלמידה בעת הייצוא</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;ברירת מחדל&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>כל הקבצים (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>ייבוא</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>ייבוא מקובץ</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>סוג הקובץ:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>קובץ לייבוא:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;עיון</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>הכנס כרטיסיות ללא קטגוריה לקטגוריה:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>הערה: כל הכרטיסיות ייתווספו לבסיס הנתונים הנוכחי.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>מחק את מידע על הלמידה בעת הייבוא</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור
</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">בסיס נתונים של מנימוסינה (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">חדש</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">אנא המתינו...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">מנימוסינה</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">למחוק כרטיסיה נוכחית?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;כן</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;לא</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">תחזור בעוד</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished">ימים.</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">החזרה הבאה: היום.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">החזרה הבאה: מחר.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">החזרה הבאה בעוד </translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> ימים.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">שאלה:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;ברירת מחדל&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">הצג &amp;תשובה</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">להתקדם לפני התכנון</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">בחרו מספר ימים לפני החזרה הבאה:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">דרגו תשובתכם:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">מתוכננות: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">לא נלמדו: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">סך הכל: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">הצג תשובה</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>מנימוסינה</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>תשובה:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>הצג תשובה</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>דרגו את תשובתכם:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;פתיחה...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;שמירה</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>שמירה &amp;בשם...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;יציאה</translation>
    </message>
    <message>
        <source>About</source>
        <translation>על התוכנה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;על התוכנה</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>הוספת כרטיסיות</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;הוספת כרטיסיות</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>הפעלת &amp;קטגוריות</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>עריכת חפיסה</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>עריכת &amp;חפיסה</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>ייב&amp;וא</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>יי&amp;צוא</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>הצג &amp;סרגל כלים</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>עריכת כרטיסיה נוכחית</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>עריכת &amp;כרטיסיה נוכחית</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>מחיקת כרטיסיה זו</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;מחיקת כרטיסיה זו</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;נקה כפילויות</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;אפשרויות מנימוסינה</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>מתחילים</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;מתחילים</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>למטה, למטה</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>רווח</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>הצג סטטיסטיקה</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>הצג &amp;סטטיסטיקה</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>עצת היום</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;עצת היום</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>סרגל הכלים הראשי (מנימוסינה)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;חפיסה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;ברירת מחדל&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>הצג כרטיס</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>שאלה:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>תשובה:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>מתחילים</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>שלום!

אני מנימוסינה, סוג של פרפר הקרוי על שם אלת הזכרון היוונית.

אני יכול לייעל עבורכם את תהליך הלמידה והשינון של עובדות ומילים, בכך שאעזור לכם להתמקד בכרטיסיות שסביר להניח שתשכחו ולא לבזבז את זמנכם על דברים שאתם יודעים היטב.

לשם כך, אני אחליט מתי לשאול אתכם את השאלות, ואתם תצטרכו לדרג כמה טוב אתם זוכרים את התשובות.

כעת, בואו נתבונן במשמעות של הדירוגים השונים.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>הקדמה</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>הדירוגים נעים בין 0 ל5-.

השתמשו בדירוגים 0 ו1- אם אינכם יודעים את התשובה עדיין, או אם שכחתם אותה. כרטיסיה עם דירוג 1 מוכרת יותר מאשר כרטיסיה עם דירוג 0, והיא תוצג לעתים רחוקות יותר.

אני אמשיך לשאול אתכם את השאלות האלו עד שתתנו להן דירוג של 2 או יותר (הדירוג המדויק אינו משנה). הדירוג 2 בעצם אומר שאתם חושבים שתצליחו לזכור את הכרטיסיה במשך יום או יומיים לפחות. הוא מסמן את המעבר מזיכרון לטווח קצר לזכרון לטווח ארוך.

אני אשמור את הכרטיסיה לתאריך מאוחר יותר, בו אני חושב שעדיין תצליחו לזכור אותה תוך מאמץ מסויים, בלי לשכוח אותה לגמרי. זוהי הדרך היעילה ביותר לתהליך הלמידה.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>דירוגים 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>אם בעתיד אשאל אתכם שאלה מוקדם מדי, ותצליחו לזכור את התשובה ללא מאמץ, דרגו את הכרטיסיה 5. אני אתחשב בזה בכך שאחכה הרבה יותר לפני שאשאל את אותה השאלה שוב.

אם אני קולע בדיוק, כך שאתם זוכרים את התשובה תוך מאמץ מסויים, דרגו 4.

מצד שני, אם נדרש מכם מאמץ ניכר כדי לזכור את התשובה, ואתם חושבים שחיכיתי יותר מדי לפני ששאלתי אתכם את השאלה, דרגו את הכרטיסיה 3.

אם אינכם זוכרים את התשובה בכלל, דרגו את הכרטיסיה 0 או 1, ואני אמשיך לשאול אתכם את השאלה עד שתחשבו שאתם יכולים לזכור אותה במשך מספר ימים.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>דירוגים 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>אם אתם מתעניינים בסטטיסטיקה, אני יכול לשמור תיעוד מפורט של תהליך הלמידה שלכם.

זאת ועוד - אם תרצו, אני יכול להעלות גרסה אנונימית לחלוטין של התיעודים האלו לאתר מרכזי עבור ניתוח, כדי שתוכלו לעזור לשפר אותי. זאת אעשה מבלי להפריע לכם. כך גם תתרמו למחקר המדעי על זיכרון לטווח ארוך.

רוקנו את התיבה הבאה אם אין ברצונכם לעשות זאת.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>שליחת תיעודים אנונימיים</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(אתם תמיד יכולים לשנות את ההגדרה הזו מאוחר יותר באמצעות &quot;אפשרויות מנימוסינה&quot; בתפריט.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>סטטיסטיקה</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>כעת אתם מוכנים להתחיל!
&lt;p&gt;
הוסיפו כרטיסיות באמצעות לחיצה על הסמל &apos;+&apos; בפינה השמאלית העליונה.
&lt;p&gt;
זכרו - אין צורך לדאוג לגבי שמירת עבודתכם. אני אעשה זאת באופן אוטומטי.
&lt;p&gt;
לקבלת התוצאות הטובות ביותר, אני מציע שתבצעו את החזרה שלכם בכל יום, למרות שאנסה להתמודד באופן הטוב ביותר אם תדחו את החזרה שלכם או אם תעדיפו להקדים את התכנון.
&lt;p&gt;
לתיעוד נוסף, בקרו ב-http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
למידה מהנה!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>מוכנים להתחיל</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>הכנסת &amp;תמונה</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>הכנסת &amp;צליל</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>קלט &amp;תלת-צדדי</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>קובץ תמונה</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>הכנסת תמונה</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>קבצי צליל</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>הכנסת צליל</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">הכרטיסיות המתוכננות לימים הבאים:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>בעוד</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>ימים:</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>מספר הכרטיסיות בעלות הדירוגים הבאים:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>דירוג</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>אין כרטיסיה נוכחית.</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>ציון:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>קלות:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>מספר חזרות:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>מספר טעויות:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>מספר ימים מאז החזרה האחרונה:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>מספר ימים עד החזרה הבאה:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>קטגוריה</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>כרטיסיות</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>סטטיסטיקה</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>לוח זמנים</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>דירוגים</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>קטגוריות</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>כרטיסיה נוכחית</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>לקבלת התוצאות הטובות ביותר, מומלץ לבצע חזרות בכל יום.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>אם לא הייתם זמינים במשך מספר ימים, אל תדאגו בקשר למצבור הלמידה שלכם. למדו כמה כרטיסים שמתחשק לכם כדי להתעדכן. היתר יתוזמן מחדש לזמן אחר בעתיד.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>ההגדרה &apos;מספר הכרטיסיות עם ציון 0 ללמוד בבת אחת&apos; קובעת כמה כרטיסיות חדשות אתם מנסים ללמוד באותו זמן. היא &lt;b&gt;לא&lt;/b&gt; אומרת לכם כמה כרטיסיות חדשות אתם צריכים ללמוד בכל יום. אתם שופטים בנוגע לזה: אתם יכולים ללמוד יותר כרטיסיות או פחות כרטיסיות, לפי ההרגשה שלכם.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>לסיכום, נסו לבצע את החזרות שלכם בכל יום. אל תדאגו יותר מדי לגבי מדד הכרטיסיות המתוכננות, ובהחלט לא לגבי מדד הכרטיסיות שלא נלמדו.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>כרטיסיות בעלות דירוג 1 שונות מכרטיסיות בעלות דירוג 0 בכל שהן מופיעות לעתים רחוקות יותר ואינן מושפעות מההגדרה &apos;מספר הכרטיסיות עם ציון 0 ללמוד בבת אחת&apos;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>ניתן להשתמש במקלדת לביצוע החזרות. המקשים אנטר (Enter) ורווח מפעילים את פעולת ברירת המחדל (&apos;הראה תשובה&apos; או &apos;דרג 4&apos;). ניתן להשתמש במקשי המספרים לצורך דירוג.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>ניתן לבחור את הקטגוריות שברצונכם ללמוד באפשרות &apos;הפעל קטגוריות&apos; בתפריט.<byte value="x9"/></translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>מומלץ לשים את כל הכרטיסיות בבסיס נתונים אחד ולהשתמש בקטגוריות כדי למיין אותן. האפשרות &apos;הפעל קטגוריות&apos; נוחה הרבה יותר מהצורך לטעון ולסגור מספר בסיסי נתונים.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>ניתן לייבא כרטיסיות במגוון רחב של תבניות: קבצי txt המופרדים באמצעות טאבים, קבצי Supermemo, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>אם יש לכם קלפים ב-Word או Excel, ייצאו אותם לקובץ txt המופרד בטאבים עם קידוד unicode UFT-8 כדי שתוכלו לייבא אותם למנימוסינה.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>אם ברצונכם להדפיס את הכרטיסיות שלכם, ייצאו אותם לקובץ txt. אותו תוכלו להדפיס ממעבד התמלילים החביב עליכם.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>אתם יכולים לחלוק את הכרטיסיות שלכם: ייצאו אותן לקובץ XML ובחרו באפשרות &apos;מחק את המידע על למידה&apos;.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>אם אתם לומדים שפה זרה בעלת כתיב שונה, גודל הגופן הבסיסי קטן מדי לפעמים. אם ברצונכם להגדיל את הסימנים האלו תוך שמירת הגודל של טקסט באנגלית, השתמשו באפשרות &apos;הגדל את הגופן של תווים שאינם לטיניים ב-X נקודות&apos;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>אתם יכולים להוסיף תמונות וצלילים לכרטיסיות שלכם. לחצו בכפתור הימני על שדה השאלה או התשובה כאשר אתם עורכים קלף כדי להראות תפריט המאפשר זאת.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>מומלץ לשמור את קבצי התמונה והצליל בתוך תיקיית ה-mnemosyne. שלך. כך קל יותר להעביר את המידע שלכם בין מחשבים שונים.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>כאשר אתם מוסיפים כרטיסיה תלת-צדדית, שני כרטיסיות רגילות יווצרו: אחת שבה השאלה היא הצורה הכתובה והתשובה היא ההגייה והתרגום, ואחת שבה השאלה היא התרגום והתשובה היא הצורה הכתובה וההגייה.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>ניתן להשתמש בתוויות HTML בסיסיות בתוך הכרטיסיות כדי לשנות את המראה שלהן.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>מנימוסינה יכול להשתמש בלטך כדי להציג נוסחאות מתמטיות. לדוגמה, &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (לשם כך, יש להתקין LaTeX ו-dvipng.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>הדרך הטובה ביותר לגבות את המידע שלכם היא להעתיק את התיקייה mnemosyne. (אם שמרתם את כל הקבצים שלכם שם) ולהעביר אותר לכונן נפרד. מנימוסינה שומר אוטומטית גיבויים מבוססי XML ב-mnemosyne/backups., אבל הם לא יעזרו לכם אם הכונן שלכם מת... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>ניתן להריץ את מנימוסינה מכונן USB. העתיקו את C:\Program Files\Mnemosyne לכונן ה-USB, ואז העתיקו את התיקייה mnemosyne. מתיקיית הבית שלכם לתוך התיקייה Mnemosyne שבכונן ה-USB.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>אם אתם משתמשים במנימוסינה במספר מחשבים, ישנו כלי שימושי הנקרא Unison שמטרתו לסייע לכם לסנכרן את המידע שלכם. ראו באתר מנימוסינה למידע נוסף.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>ניתן למיין את הכרטיסיות בחלון &apos;ערוך כרטיסיות&apos; לפי תשובה או קטגוריה באמצעות לחיצה על כותרת העמודה המתאימה. לחיצה שנייה משנה את סדר המיון.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>אם אתם רוצים שליטה בפרטים הקטנים בהתנהגות של לטך, ראו את ההסבר עבור התגיות &lt;$$&gt;...&lt;/$$&gt; ו-&lt;latex&gt;...&lt;/latex&gt; באתר מנימוסינה.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>משתמשים מתקדמים יכולים להתאים אישית את מנימוסינה בצורה נרחבת יותר באמצעות עריכת הקובץ config.py בתיקייה mnemosyne.. הם גם יכולים להתקין תוספים כדי להתאימו אישית אף יותר.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>עצת היום</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;הידעת...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;הראה עצות בעת ההפעלה</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>ה&amp;קודם</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>ה&amp;בא</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
